import {HTTP_INTERCEPTORS, HttpClient, HttpClientModule} from '@angular/common/http';
import {NgModule} from '@angular/core';
import {BrowserModule} from '@angular/platform-browser';
import {AccessModule} from '@app/access/access.module';
import {DepositModule} from '@app/deposit/deposit.module';
import {DepositState} from '@app/deposit/deposit.state';
import {SharedModule} from '@app/shared/shared.module';
import {TranslateLoader, TranslateModule} from '@ngx-translate/core';
import {TranslateHttpLoader} from '@ngx-translate/http-loader';
import {NgxsModule} from '@ngxs/store';

import {AuthConfig, JwksValidationHandler, OAuthModule, OAuthModuleConfig, OAuthStorage, ValidationHandler} from 'angular-oauth2-oidc';

import {AppRoutingModule} from './app-routing.module';
import {AppComponent} from './app.component';
import {AppService} from './app.service';
import {authConfig, authModuleConfig} from './auth.config';
import {HomeComponent} from './components/home/home.component';
import {LoginComponent} from './components/login/login.component';
import {PageNotFoundComponent} from './components/page-not-found/page-not-found.component';
import {DlcmInterceptor} from './dlcm.interceptor';

@NgModule({
  declarations: [
    AppComponent,
    HomeComponent,
    PageNotFoundComponent,
    LoginComponent,
  ],
  imports: [
    BrowserModule,
    AppRoutingModule,
    NgxsModule.forRoot([
      DepositState,
      // AccessState,
    ]),
    HttpClientModule,
    OAuthModule.forRoot(authModuleConfig),
    TranslateModule.forRoot({
      loader: {
        provide: TranslateLoader,
        useFactory: HttpLoaderFactory,
        deps: [HttpClient],
      },
    }),
    SharedModule,
    AccessModule,
    DepositModule,
  ],
  providers: [
    AppService,
    {provide: OAuthModuleConfig, useValue: authModuleConfig},
    {provide: ValidationHandler, useClass: JwksValidationHandler},
    // {provide: OAuthStorage, useClass: DlcmStorage},
    {provide: OAuthStorage, useValue: sessionStorage},
    {provide: AuthConfig, useValue: authConfig},
    {
      provide: HTTP_INTERCEPTORS,
      useClass: DlcmInterceptor,
      multi: true,
    },
  ],
  bootstrap: [AppComponent],
})
export class AppModule {
}


// required for AOT compilation
export function HttpLoaderFactory(http: HttpClient) {
  return new TranslateHttpLoader(http);
}
